use bevy::prelude::*;

pub struct Plugin;
impl bevy::prelude::Plugin for Plugin {
    fn build(&self, app: &mut App) {
        app.add_systems(Startup, setup);
    }
}

#[derive(Component)]
pub struct CameraMarker;

fn setup(mut cmds: Commands, window: Query<&Window>) {
    let zoom = 2. / window.single().width().min(window.single().height());
    cmds.spawn((
        CameraMarker,
        Camera3d {
            ..Default::default()
        },
        Transform::from_scale(Vec3::new(zoom, zoom, zoom))
            .with_translation(Vec3::new(0., -1., 1.))
            .looking_to(Vec3::new(0., 1., -1.), Vec3::Y),
    ));
    cmds.spawn(
        DirectionalLightBundle {
            directional_light: DirectionalLight {
                color: Color::WHITE,
                illuminance: 17000.,
                //shadows_enabled: true,
                ..Default::default()
            },
            transform: Transform::default().looking_to(Vec3::new(1., -1., -1.), Vec3::ZERO),
            ..Default::default()
        }
    );
}
